EnumOptionMap

Struct EnumOptionMap 

pub struct EnumOptionMap<T: EnumArrayHelper<V> + EnumSetHelper<BitsetWord>, V, BitsetWord: BitsetWordTrait = u8> { /* private fields */ }
A partial map from enumoid T to values V.

The optional type parameter BitsetWord is passed on to an embedded EnumSet which is used to store the validity bitmap.

Implementations

Source

impl<T: EnumArrayHelper<V> + EnumSetHelper<BitsetWord>, V, BitsetWord: BitsetWordTrait> EnumOptionMap<T, V, BitsetWord>

pub fn new() -> Self

Creates a new empty map.

pub fn get_by_index(&self, index: EnumIndex<T>) -> Option<&V>

Returns a reference to the value associated with a given index, or None if the index has no value in the map.

pub fn get(&self, key: T) -> Option<&V>

Returns a reference to the value associated with a given key, or None if the key has no value in the map.

pub fn get_by_index_mut(&mut self, index: EnumIndex<T>) -> Option<&mut V>

Returns a mutable reference to the value associated with a given index, or None if the index has no value in the map.

pub fn get_mut(&mut self, key: T) -> Option<&mut V>

Returns a mutable reference to the value associated with a given key, or None if the key has no value in the map.

pub fn set_by_index( &mut self, index: EnumIndex<T>, value: Option<V>, ) -> Option<V>

Sets the value associated with a given index and returns the old value if one was present.

pub fn set(&mut self, key: T, value: Option<V>) -> Option<V>

Sets the value associated with a given key and returns the old value if one was present.

pub fn insert_by_index(&mut self, index: EnumIndex<T>, value: V) -> Option<V>

Adds a value at the given index to the map and returns the old value if one was present.

pub fn insert(&mut self, key: T, value: V) -> Option<V>

Adds a value with the given key to the map and returns the old value if one was present.

pub fn remove_by_index(&mut self, index: EnumIndex<T>) -> Option<V>

Removes any value at the given index from the map and returns it if one was present.

pub fn remove(&mut self, key: T) -> Option<V>

Removes any value with the given key from the map and returns it if one was present.

pub fn swap_by_index(&mut self, a: EnumIndex<T>, b: EnumIndex<T>)

Swaps two elements in the map by index.

pub fn swap(&mut self, a: T, b: T)

Swaps two elements in the map.

pub fn clear(&mut self)

Clears all the elements from the map.

pub fn is_empty(&self) -> bool

Returns true if the map is empty.

pub fn is_full(&self) -> bool

Returns true if the map is fully populated.

pub fn is_vec(&self) -> Option<EnumSize<T>>

Returns the size of a vector needed to represent the map, or None if the map is not representable by a vector.

A map is representable by vector if all the populated values are contiguous with the first key, or if the map is empty.

pub fn contains_index(&self, index: EnumIndex<T>) -> bool

Returns true if the map contains the index.

pub fn contains(&self, value: T) -> bool

Returns true if the map contains the key.

pub fn iter(&self) -> EnumOptionMapIter<'_, T, V, BitsetWord>

Returns an iterator over the keys and values.

pub fn iter_mut(&mut self) -> EnumOptionMapIterMut<'_, T, V, BitsetWord>

Returns a mutable iterator over the keys and values.

pub fn count(&self) -> usize

Returns the number of populated keys in the map.

pub fn keys(&self) -> &EnumSet<T, BitsetWord>

Returns a reference to the set of populated keys.